#!/usr/bin/wish8.5

#######################################
#  xcaliber-gui
#
#	Copyright © 2001 Zaheer Kazi
# Copyright © 2010 Pascal Reinhard <dev@ovocean.com>
#
#	xcaliber-gui is free software: you can redistribute it and/or modify
#	it under the terms of the GNU General Public License version 2 as published by
#	the Free Software Foundation.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program.  If not, see <http://www.gnu.org/licenses/>.
#######################################

# You may change these default settings

set brightness 256
set bRed -0
set bGreen -0
set bBlue -0

set gamma 1.15
set gRed 0
set gGreen 0
set gBlue 0

# End of user serviceable parts


wm title . Xcaliber


# Left frame

frame .left -borderwidth 10
pack .left -side left -fill x

set test_pattern_grey  /usr/share/xcaliber/test_pattern_grey.ppm
set test_pattern       /usr/share/xcaliber/test_pattern.ppm
set test_pattern_lcd   /usr/share/xcaliber/test_pattern_lcd.ppm

set test_pattern_grey [image create photo -file $test_pattern_grey]
set test_pattern [image create photo -file $test_pattern]
set test_pattern_lcd [image create photo -file $test_pattern_lcd]

label .left.test_pattern_grey -image $test_pattern_grey
label .left.tp_grey -text "The greyscale gradient below must look evenly stepped. \nUse the Gamma slider to adjust."

label .left.test_pattern -image $test_pattern
label .left.tp -text "\nThese squares and their frames must blend together. \nThey are not usable with most LCD screens but can help to \ncalibrate colors relative to each other. Use the Gamma slider(s)."

label .left.test_pattern_lcd -image $test_pattern_lcd 
label .left.tp_lcd -text "\nThese ones are adjusted empirically using the developer's cheap LCD \nscreen, thus they are not to be used to calibrate yours but can reassure..."


# Right frame

frame .right -borderwidth 10
pack .right -side left -fill x

scale .right.brightness \
		-label "Brightness" \
    -from 0 -to 256  \
    -digits 0 \
    -length 275 \
    -resolution 1 \
    -troughcolor white \
    -variable brightness \
    -orient horizontal \
    -command goCaliber

scale .right.bRed \
    -from -100 -to 0 \
    -digits 0 \
    -length 275 \
    -resolution 1 \
    -troughcolor red \
    -variable bRed \
    -orient horizontal \
    -command goCaliber

scale .right.bGreen \
    -from -100 -to 0 \
    -digits 0 \
    -length 275 \
    -resolution 1 \
    -troughcolor green \
    -variable bGreen \
    -orient horizontal \
    -command goCaliber

scale .right.bBlue \
    -from -100 -to 0 \
    -digits 0 \
    -length 275 \
    -resolution 1 \
    -troughcolor blue \
    -variable bBlue \
    -orient horizontal \
    -command goCaliber

scale .right.gamma \
		-label "Gamma  (system default = 1.15)" \
    -from 0.5 -to 4  \
    -digits 3 \
    -length 275 \
    -resolution .01 \
    -troughcolor black \
    -variable gamma \
    -orient horizontal \
    -command goCaliber \

scale .right.gRed \
    -from -1 -to +1 \
    -digits 3 \
    -length 275 \
    -resolution 0.01 \
    -troughcolor red \
    -variable gRed \
    -orient horizontal \
    -command goCaliber

scale .right.gGreen \
    -from -1.00 -to +1.00 \
    -digits 3 \
    -length 275 \
    -resolution 0.01 \
    -troughcolor green \
    -variable gGreen \
    -orient horizontal \
    -command goCaliber

scale .right.gBlue \
    -from -1 -to +1 \
    -digits 3 \
    -length 275 \
    -resolution 0.01 \
    -troughcolor blue \
    -variable gBlue \
    -orient horizontal \
    -command goCaliber

label .right.commandInstruction -text "Copy this ugly command (scroll to the right)\n and launch it at your system's startup:"

entry .right.command -relief sunken -width 38

label .right.tip -text "Tip: The following commands will respectively \nreduce and increase global brightness from 10: \nxcaliber -s -10 \nxcaliber -s 10 "

proc goCaliber {void} {
  global brightness bRed bGreen bBlue gamma gRed gGreen gBlue command

	set bR [expr $brightness + $bRed]
	set bG [expr $brightness + $bGreen]
	set bB [expr $brightness + $bBlue]
	if {$bR < 1}	{set bR 1}
	if {$bG < 1}	{set bG 1}
	if {$bB < 1} {set bB 1}

	set gR [expr $gamma + $gRed]
	set gG [expr $gamma + $gGreen]
	set gB [expr $gamma + $gBlue]
	if {$gR < 0.1}	{set gR 0.1}
	if {$gG < 0.1}	{set gG 0.1}
	if {$gB < 0.1} {set gB 0.1}

  catch {exec xcaliber --bR=$bR --bG=$bG --bB=$bB --gR=$gR --gG=$gG --gB=$gB } result
	set command "xcaliber --bR=$bR --bG=$bG --bB=$bB --gR=$gR --gG=$gG --gB=$gB"
	.right.command configure -textvariable command
}


pack  .left.tp_grey \
			.left.test_pattern_grey  \
			.left.tp \
			.left.test_pattern \
			.left.tp_lcd \
			.left.test_pattern_lcd

pack  .right.brightness \
			.right.bRed \
			.right.bGreen \
			.right.bBlue

pack	.right.gamma -pady "30 0"
pack	.right.gRed \
			.right.gGreen \
			.right.gBlue

pack  .right.commandInstruction -pady "30 0"
pack	.right.command

pack	.right.tip -pady "20 10"










